@@ -1,5 +1,5 @@
-#  tests for netcdf4-1.5.1-py37h2b7c3b1_0 (this is a generated file);
-print('===== testing package: netcdf4-1.5.1-py37h2b7c3b1_0 =====');
+#  tests for netcdf4-1.5.1.1-py37h2b7c3b1_0 (this is a generated file);
+print('===== testing package: netcdf4-1.5.1.1-py37h2b7c3b1_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import netCDF4
@@ -17,7 +17,7 @@ with netCDF4.Dataset(url) as nc:
     nc['tidenames'][:]
 #  --- run_test.py (end) ---
 
-print('===== netcdf4-1.5.1-py37h2b7c3b1_0 OK =====');
+print('===== netcdf4-1.5.1.1-py37h2b7c3b1_0 OK =====');
 print("import: 'netCDF4'")
 import netCDF4
 
